@@ -20,14 +20,14 @@
  */
 /*
   File:      actions.cpp
-  Version:   $Rev: 1039 $
+  Version:   $Rev: 1143 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   08-Dec-03, ahu: created
              30-Apr-06, Roger Larsson: Print filename if processing multiple files
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: actions.cpp 1039 2007-02-02 10:09:31Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: actions.cpp 1143 2007-07-10 08:21:10Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -753,6 +753,7 @@ namespace Action {
     }
 
     int Rename::run(const std::string& path)
+    {
     try {
         if (!Exiv2::fileExists(path, true)) {
             std::cerr << path
@@ -775,14 +776,19 @@ namespace Action {
         Exiv2::ExifKey key("Exif.Photo.DateTimeOriginal");
         Exiv2::ExifData::iterator md = exifData.findKey(key);
         if (md == exifData.end()) {
-            std::cerr << _("Metadatum with key") << " `" << key << "' "
-                      << _("not found in the file") << " " << path << "\n";
+            key = Exiv2::ExifKey("Exif.Image.DateTime");
+            md = exifData.findKey(key);
+        }
+        if (md == exifData.end()) {
+            std::cerr << _("Neither tag") << " `Exif.Photo.DateTimeOriginal' "
+                      << _("nor") << " `Exif.Image.DateTime' "
+                      << _("found in the file") << " " << path << "\n";
             return 1;
         }
         std::string v = md->toString();
         if (v.length() == 0 || v[0] == ' ') {
-            std::cerr << _("Image file creation timestamp not set in the file") << " "
-                      << path << "\n";
+            std::cerr << _("Image file creation timestamp not set in the file")
+                      << " " << path << "\n";
             return 1;
         }
         struct tm tm;
@@ -819,7 +825,7 @@ namespace Action {
         std::cerr << "Exiv2 exception in rename action for file " << path
                   << ":\n" << e << "\n";
         return 1;
-    } // Rename::run
+    }} // Rename::run
 
     Rename::AutoPtr Rename::clone() const
     {
