@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004, 2005, 2006 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2007 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -22,7 +22,7 @@
   @file    actions.hpp
   @brief   Implements base class Task, TaskFactory and the various supported
            actions (derived from Task).
-  @version $Rev: 832 $
+  @version $Rev: 1040 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @date    11-Dec-03, ahu: created
@@ -308,20 +308,24 @@ namespace Action {
         typedef std::auto_ptr<Modify> AutoPtr;
         AutoPtr clone() const;
         Modify() {}
+        //! Apply modification commands to the \em pImage
+        static void applyCommands(Exiv2::Image* pImage);
 
     private:
         virtual Modify* clone_() const;
         //! Copy contructor needed because of AutoPtr member
         Modify(const Modify& /*src*/) : Task() {}
 
-        //! Add a metadatum according to \em modifyCmd
-        void addMetadatum(const ModifyCmd& modifyCmd);
-        //! Set a metadatum according to \em modifyCmd
-        void setMetadatum(const ModifyCmd& modifyCmd);
-        //! Delete a metadatum according to \em modifyCmd
-        void delMetadatum(const ModifyCmd& modifyCmd);
+        //! Add a metadatum to \em pImage according to \em modifyCmd
+        static void addMetadatum(Exiv2::Image* pImage,
+                                 const ModifyCmd& modifyCmd);
+        //! Set a metadatum in \em pImage according to \em modifyCmd
+        static void setMetadatum(Exiv2::Image* pImage,
+                                 const ModifyCmd& modifyCmd);
+        //! Delete a metadatum from \em pImage according to \em modifyCmd
+        static void delMetadatum(Exiv2::Image* pImage,
+                                 const ModifyCmd& modifyCmd);
 
-        Exiv2::Image::AutoPtr image_;        //!< Image to modify
     }; // class Modify
 
     /*!
