@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004, 2005, 2006 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2007 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -23,7 +23,7 @@
   @brief   Canon MakerNote.<BR>References:<BR>
            <a href="http://www.burren.cx/david/canon.html">EXIF MakerNote of Canon</a> by David Burren<br>
            <a href="http://www.sno.phy.queensu.ca/~phil/exiftool/TagNames/Canon.html">Canon makernote tags</a> by Phil Harvey
-  @version $Rev: 870 $
+  @version $Rev: 1039 $
   @author  <a href="mailto:ahuggel@gmx.net">Andreas Huggel (ahu)</a><br>
            <a href="mailto:david@edeca.net">David Cannings (dc)</a>
   @date    18-Feb-04, ahu: created<BR>
@@ -127,6 +127,18 @@ namespace Exiv2 {
         long size() const;
         AutoPtr create(bool alloc =true) const;
         AutoPtr clone() const;
+        //! Return read-only list of built-in Canon tags
+        static const TagInfo* tagList();
+        //! Return read-only list of built-in Canon Camera Settings tags
+        static const TagInfo* tagListCs();
+        //! Return read-only list of built-in Canon Shot Info tags
+        static const TagInfo* tagListSi();
+        //! Return read-only list of built-in Canon Panorama tags
+        static const TagInfo* tagListPa();
+        //! Return read-only list of built-in Canon Custom Function tags
+        static const TagInfo* tagListCf();
+        //! Return read-only list of built-in Canon Picture Info tags
+        static const TagInfo* tagListPi();
         //@}
 
         //! @name Print functions for Canon %MakerNote tags
