@@ -20,13 +20,13 @@
  */
 /*
   File:      error.cpp
-  Version:   $Rev: 1048 $
+  Version:   $Rev: 1119 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   02-Apr-05, ahu: created
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: error.cpp 1048 2007-02-07 14:27:39Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: error.cpp 1119 2007-06-09 09:09:23Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -77,8 +77,8 @@ namespace Exiv2 {
         ErrMsg( 32, N_("Setting %1 in %2 images is not supported")), // %1=metadata type, %2=image format
         ErrMsg( 33, N_("This does not look like a CRW image")),
         ErrMsg( 34, N_("%1: Not supported")), // %1=function
-        ErrMsg( 35, N_("ImageFactory registry full")),
-        ErrMsg( 36, N_("Failed to decode %1 metadata")), // %1=type of metadata (Exif, IPTC)
+        // 35
+        // 36
         ErrMsg( 37, N_("Size of %1 JPEG segment is larger than 65535 bytes")), // %1=type of metadata (Exif, IPTC, JPEG comment)
 
         // Last error message (message is not used)
@@ -94,34 +94,33 @@ namespace Exiv2 {
         return idx;
     }
 
-    std::string Error::what() const
+    void Error::setMsg()
     {
         int idx = errorIdx(code_);
-        std::string msg = std::string(_(errMsg_[idx].message_));
+        msg_ = std::string(_(errMsg_[idx].message_));
         std::string::size_type pos;
-        pos = msg.find("%0");
+        pos = msg_.find("%0");
         if (pos != std::string::npos) {
-            msg.replace(pos, 2, toString(code_));
+            msg_.replace(pos, 2, toString(code_));
         }
         if (count_ > 0) {
-            pos = msg.find("%1");
+            pos = msg_.find("%1");
             if (pos != std::string::npos) {
-                msg.replace(pos, 2, arg1_);
+                msg_.replace(pos, 2, arg1_);
             }
         }
         if (count_ > 1) {
-            pos = msg.find("%2");
+            pos = msg_.find("%2");
             if (pos != std::string::npos) {
-                msg.replace(pos, 2, arg2_);
+                msg_.replace(pos, 2, arg2_);
             }
         }
         if (count_ > 2) {
-            pos = msg.find("%3");
+            pos = msg_.find("%3");
             if (pos != std::string::npos) {
-                msg.replace(pos, 2, arg3_);
+                msg_.replace(pos, 2, arg3_);
             }
         }
-        return msg;
     }
 
 }                                       // namespace Exiv2
