@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004, 2005, 2006 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2007 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,14 +20,14 @@
  */
 /*
   File:      exif.cpp
-  Version:   $Rev: 994 $
+  Version:   $Rev: 1039 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   26-Jan-04, ahu: created
              11-Feb-04, ahu: isolated as a component
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: exif.cpp 994 2006-11-25 15:38:38Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: exif.cpp 1039 2007-02-02 10:09:31Z ahuggel $")
 
 // Define DEBUG_MAKERNOTE to output debug information to std::cerr, e.g, by
 // calling make like this: make DEFS=-DDEBUG_MAKERNOTE exif.o
@@ -483,12 +483,12 @@ namespace Exiv2 {
         assert(tmpIfd0.get() != 0);
         rc = tmpIfd0->read(tmpData.pData_,
                            tmpData.size_,
-                           tmpTiffHeader->offset(), 
+                           tmpTiffHeader->offset(),
                            tmpTiffHeader->byteOrder());
         if (rc) return rc; // no point to continue if there is no IFD0
 
         // We have at least a valid IFD0, so replace old metadata with new now
-        // After this point we only return 0 (success), although parts of the 
+        // After this point we only return 0 (success), although parts of the
         // Exif data may be missing due to problems reading specific IFDs.
 
         this->clear(); // Deletes existing pointers
@@ -1122,9 +1122,10 @@ namespace Exiv2 {
                 break;
             }
             // Make sure that the size of the Exifdatum fits the available size
-            // of the entry
+            // of the entry and the types are the same
             if (   md->size() > rc.second->size()
-                || md->sizeDataArea() > rc.second->sizeDataArea()) {
+                || md->sizeDataArea() > rc.second->sizeDataArea()
+                || md->typeId() != rc.second->type()) {
                 compatible = false;
                 break;
             }
