@@ -22,13 +22,13 @@
   Abstract:  Command line program to display and manipulate image %Exif data
 
   File:      exiv2.cpp
-  Version:   $Rev: 1039 $
+  Version:   $Rev: 1120 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   10-Dec-03, ahu: created
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: exiv2.cpp 1039 2007-02-02 10:09:31Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: exiv2.cpp 1120 2007-06-09 10:02:54Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -138,22 +138,24 @@ int main(int argc, char* const argv[])
     assert(task.get());
 
     // Process all files
+    int rc = 0;
     int n = 1;
     int s = static_cast<int>(params.files_.size());
     int w = s > 9 ? s > 99 ? 3 : 2 : 1;
-    Params::Files::const_iterator e = params.files_.end();
-    for (Params::Files::const_iterator i = params.files_.begin(); i != e; ++i) {
+    for (Params::Files::const_iterator i = params.files_.begin(); 
+         i != params.files_.end(); ++i) {
         if (params.verbose_) {
             std::cout << _("File") << " " << std::setw(w) << n++ << "/" << s << ": "
                       << *i << std::endl;
         }
-        task->run(*i);
+        int ret = task->run(*i);
+        if (rc == 0) rc = ret;
     }
 
     taskFactory.cleanup();
     params.cleanup();
 
-    return 0;
+    return rc;
 } // main
 
 // *****************************************************************************
@@ -334,16 +336,23 @@ int Params::evalRename(int opt, const std::string& optarg)
     case Action::none:
         action_ = Action::rename;
         switch (opt) {
-        case 'r': format_ = optarg; break;
+        case 'r': 
+            format_ = optarg; 
+            formatSet_ = true;
+            break;
         case 't': timestamp_ = true; break;
         case 'T': timestampOnly_ = true; break;
         }
         break;
     case Action::rename:
-        if (opt == 'r' && !format_.empty()) {
+        if (opt == 'r' && (formatSet_ || timestampOnly_)) {
             std::cerr << progname()
                       << ": " << _("Ignoring surplus option") << " -r \"" << optarg << "\"\n";
         }
+        else {
+            format_ = optarg; 
+            formatSet_ = true;
+        }
         break;
     default:
         std::cerr << progname()
