@@ -20,14 +20,14 @@
  */
 /*
   File:      ifd.cpp
-  Version:   $Rev: 1039 $
+  Version:   $Rev: 1133 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   26-Jan-04, ahu: created
              11-Feb-04, ahu: isolated as a component
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: ifd.cpp 1039 2007-02-02 10:09:31Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: ifd.cpp 1133 2007-07-02 03:06:18Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -356,7 +356,19 @@ namespace Exiv2 {
                 pe.tag_ = getUShort(buf + o, byteOrder);
                 pe.type_ = getUShort(buf + o + 2, byteOrder);
                 pe.count_ = getULong(buf + o + 4, byteOrder);
-                pe.size_ = pe.count_ * TypeInfo::typeSize(TypeId(pe.type_));
+                uint32_t ts = TypeInfo::typeSize(TypeId(pe.type_));
+                if (pe.count_ >= 0x10000000) {
+#ifndef SUPPRESS_WARNINGS
+                    std::cerr << "Warning: "
+                              << ExifTags::ifdName(ifdId_) << " tag 0x"
+                              << std::setw(4) << std::setfill('0') << std::hex
+                              << pe.tag_ << " has invalid size "
+                              << std::dec << pe.count_ << "*" << ts 
+                              << "; truncating the data.\n";
+#endif
+                    pe.count_ = 0;
+                }
+                pe.size_ = pe.count_ * ts;
                 pe.offsetLoc_ = o + 8 - shift;
                 pe.offset_ = pe.size_ > 4 ? getLong(buf + o + 8, byteOrder) : 0;
                 preEntries.push_back(pe);
