@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004, 2005, 2006 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2007 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,7 +20,7 @@
  */
 /*
   File:      image.cpp
-  Version:   $Rev: 832 $
+  Version:   $Rev: 1046 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
              Brad Schick (brad) <brad@robotbattle.com>
   History:   26-Jan-04, ahu: created
@@ -30,7 +30,7 @@
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: image.cpp 832 2006-06-21 09:16:36Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: image.cpp 1046 2007-02-06 15:00:23Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -44,6 +44,16 @@ EXIV2_RCSID("@(#) $Id: image.cpp 832 2006-06-21 09:16:36Z ahuggel $")
 #include "error.hpp"
 #include "futils.hpp"
 
+#include "cr2image.hpp"
+#include "crwimage.hpp"
+#include "jpgimage.hpp"
+#include "mrwimage.hpp"
+#ifdef EXV_HAVE_LIBZ
+# include "pngimage.hpp"
+#endif // EXV_HAVE_LIBZ
+#include "rafimage.hpp"
+#include "tiffimage.hpp"
+
 // + standard includes
 #include <cerrno>
 #include <cstdio>
@@ -62,33 +72,127 @@ EXIV2_RCSID("@(#) $Id: image.cpp 832 2006-06-21 09:16:36Z ahuggel $")
 // class member definitions
 namespace Exiv2 {
 
+    const ImageFactory::Registry ImageFactory::registry_[] = {
+        //image type       creation fct     type check  Exif mode    IPTC mode    Comment mode
+        //---------------  ---------------  ----------  -----------  -----------  ------------
+        { ImageType::jpeg, newJpegInstance, isJpegType, amReadWrite, amReadWrite, amReadWrite },
+        { ImageType::exv,  newExvInstance,  isExvType,  amReadWrite, amReadWrite, amReadWrite },
+        { ImageType::cr2,  newCr2Instance,  isCr2Type,  amRead,      amRead,      amNone      },
+        { ImageType::crw,  newCrwInstance,  isCrwType,  amReadWrite, amNone,      amReadWrite },
+        { ImageType::mrw,  newMrwInstance,  isMrwType,  amRead,      amRead,      amNone      },
+        { ImageType::tiff, newTiffInstance, isTiffType, amRead,      amRead,      amNone      },
+#ifdef EXV_HAVE_LIBZ
+        { ImageType::png,  newPngInstance,  isPngType,  amRead,      amRead,      amNone      },
+#endif // EXV_HAVE_LIBZ
+        { ImageType::raf,  newRafInstance,  isRafType,  amRead,      amRead,      amNone      },
+        // End of list marker
+        { ImageType::none, 0,               0,          amNone,      amNone,      amNone      }
+    };
+
+    bool ImageFactory::Registry::operator==(const int& imageType) const
+    {
+        return imageType == imageType_;
+    }
+
+    Image::Image(int              imageType, 
+                 uint16_t         supportedMetadata,
+                 BasicIo::AutoPtr io)
+        : io_(io),
+          imageType_(imageType),
+          supportedMetadata_(supportedMetadata)
+    {
+    }
+
+    void Image::clearMetadata()
+    {
+        clearExifData();
+        clearIptcData();
+        clearComment();
+    }
+
+    void Image::setMetadata(const Image& image)
+    {
+        setExifData(image.exifData());
+        setIptcData(image.iptcData());
+        setComment(image.comment());
+    }
+
+    void Image::clearExifData()
+    {
+        exifData_.clear();
+    }
+
+    void Image::setExifData(const ExifData& exifData)
+    {
+        exifData_ = exifData;
+    }
+
+    void Image::clearIptcData()
+    {
+        iptcData_.clear();
+    }
+
+    void Image::setIptcData(const IptcData& iptcData)
+    {
+        iptcData_ = iptcData;
+    }
+
+    void Image::clearComment()
+    {
+        comment_.erase();
+    }
+
+    void Image::setComment(const std::string& comment)
+    {
+        comment_ = comment;
+    }
+
+    bool Image::good() const
+    {
+        if (io_->open() != 0) return false;
+        IoCloser closer(*io_);
+        return ImageFactory::checkType(imageType_, *io_, false);
+    }
+
     bool Image::supportsMetadata(MetadataId metadataId) const
     {
         return (supportedMetadata_ & metadataId) != 0;
     }
 
-    const ImageFactory::Registry* ImageFactory::find(int imageType)
+    AccessMode Image::checkMode(MetadataId metadataId) const
     {
-        for (unsigned int i = 0; registry_[i].imageType_ != ImageType::none; ++i) {
-            if (registry_[i].imageType_ == imageType) return &registry_[i];
-        }
-        return 0;
+        return ImageFactory::checkMode(imageType_, metadataId);
     }
 
-    void ImageFactory::registerImage(int            type,
-                                     NewInstanceFct newInst,
-                                     IsThisTypeFct  isType)
+    AccessMode ImageFactory::checkMode(int type, MetadataId metadataId)
     {
-        unsigned int i = 0;
-        for (; i < MAX_IMAGE_FORMATS; ++i) {
-            if (registry_[i].imageType_ == ImageType::none) {
-                registry_[i] = Registry(type, newInst, isType);
-                break;
-            }
+        const Registry* r = find(registry_, type);
+        if (!r) throw Error(13, type);
+        AccessMode am = amNone;
+        switch (metadataId) {
+        case mdExif:
+            am = r->exifSupport_;
+            break;
+        case mdIptc:
+            am = r->iptcSupport_;
+            break;
+        case mdComment:
+            am = r->commentSupport_;
+            break;
+        // no default: let the compiler complain
         }
-        if (i == MAX_IMAGE_FORMATS) throw Error(35);
+        return am;
     }
 
+    bool ImageFactory::checkType(int type, BasicIo& io, bool advance)
+    {
+        const Registry* r = find(registry_, type);
+        if (0 != r) {
+            return r->isThisType_(io, advance);
+        }
+        return false;
+    } // ImageFactory::checkType
+
     int ImageFactory::getType(const std::string& path)
     {
         FileIo fileIo(path);
@@ -169,7 +273,7 @@ namespace Exiv2 {
                                         BasicIo::AutoPtr io)
     {
         // BasicIo instance does not need to be open
-        const Registry* r = find(type);
+        const Registry* r = find(registry_, type);
         if (0 != r) {
             return r->newInstance_(io, true);
         }
