@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004, 2005, 2006 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2007 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,13 +20,13 @@
  */
 /*
   File:      iptc.cpp
-  Version:   $Rev: 988 $
+  Version:   $Rev: 1039 $
   Author(s): Brad Schick (brad) <brad@robotbattle.com>
   History:   31-July-04, brad: created
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: iptc.cpp 988 2006-11-21 16:51:04Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: iptc.cpp 1039 2007-02-02 10:09:31Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -165,7 +165,16 @@ namespace Exiv2 {
                 sizeData = getUShort(pRead, bigEndian);
                 pRead += 2;
             }
-            readData(dataSet, record, pRead, sizeData);
+            if (pRead + sizeData <= buf + len) {
+                readData(dataSet, record, pRead, sizeData);
+            }
+#ifndef SUPPRESS_WARNINGS
+            else {
+                std::cerr << "Warning: "
+                          << "IPTC dataset " << IptcKey(dataSet, record)
+                          << " has invalid size " << sizeData << "; skipped.\n";
+            }
+#endif
             pRead += sizeData;
         }
 
@@ -183,6 +192,15 @@ namespace Exiv2 {
             IptcKey key(dataSet, record);
             add(key, value.get());
         }
+        else if (1 == rc) {
+            // If the first attempt failed, try with a string value
+            value = Value::create(string);
+            int rc = value->read(data, sizeData, bigEndian);
+            if (0 == rc) {
+                IptcKey key(dataSet, record);
+                add(key, value.get());
+            }
+        }
         return rc;
     }
 
