@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004, 2005, 2006 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2007 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -21,7 +21,7 @@
 /*!
   @file    iptc.hpp
   @brief   Encoding and decoding of IPTC data
-  @version $Rev: 988 $
+  @version $Rev: 1040 $
   @author  Brad Schick (brad)
            <a href="mailto:brad@robotbattle.com">brad@robotbattle.com</a>
   @date    31-Jul-04, brad: created
@@ -341,16 +341,13 @@ namespace Exiv2 {
         //! End of the metadata
         iterator end() { return iptcMetadata_.end(); }
         /*!
-          @brief Find a Iptcdatum with the given key, return an iterator to it.
-                 If multiple entries with the same key exist, it is undefined
-                 which of the matching metadata is found.
+          @brief Find the first Iptcdatum with the given key, return an iterator
+                 to it.
          */
         iterator findKey(const IptcKey& key);
         /*!
-          @brief Find a Iptcdatum with the given record and dataset it,
-                return a const iterator to it. If multiple entries with the
-                same Ids exists, it is undefined which of the matching
-                metadata is found.
+          @brief Find the first Iptcdatum with the given record and dataset it,
+                return a const iterator to it.
          */
         iterator findId(uint16_t dataset,
                         uint16_t record = IptcDataSets::application2);
@@ -370,16 +367,13 @@ namespace Exiv2 {
          */
         DataBuf copy() const;
         /*!
-          @brief Find an Iptcdatum with the given key, return a const iterator
-                 to it.  If multiple metadata with the same key exist it is
-                 undefined which of the matching metadata is found.
+          @brief Find the first Iptcdatum with the given key, return a const
+                 iterator to it.
          */
         const_iterator findKey(const IptcKey& key) const;
         /*!
-          @brief Find a Iptcdatum with the given record and dataset number,
-                return a const iterator to it.  If multiple metadata with the
-                same Ids exist it is undefined which of the matching
-                metadata is found.
+          @brief Find the first Iptcdatum with the given record and dataset
+                 number, return a const iterator to it.
          */
         const_iterator findId(uint16_t dataset,
                               uint16_t record = IptcDataSets::application2) const;
