@@ -20,7 +20,7 @@
  */
 /*
   File:      jpgimage.cpp
-  Version:   $Rev: 1046 $
+  Version:   $Rev: 1126 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
              Brad Schick (brad) <brad@robotbattle.com>
   History:   15-Jan-05, brad: split out from image.cpp
@@ -28,7 +28,7 @@
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: jpgimage.cpp 1046 2007-02-06 15:00:23Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: jpgimage.cpp 1126 2007-06-14 13:49:55Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -207,13 +207,15 @@ namespace Exiv2 {
 
         // Markers can start with any number of 0xff
         while ((c=io_->getb()) == 0xff) {
-            if (c == EOF) return -1;
+            if (c == EOF) return -2;
         }
         return c;
     }
 
     void JpegBase::readMetadata()
     {
+        int rc = 0; // Todo: this should be the return value
+
         if (io_->open() != 0) throw Error(9, io_->path(), strError());
         IoCloser closer(*io_);
         // Ensure that this is the correct image type
@@ -238,18 +240,30 @@ namespace Exiv2 {
             uint16_t size = getUShort(buf.pData_, bigEndian);
 
             if (marker == app1_ && memcmp(buf.pData_ + 2, exifId_, 6) == 0) {
-                if (size < 8) throw Error(15);
-                // Seek to begining and read the Exif data
+                if (size < 8) {
+                    rc = 1;
+                    break;
+                }
+                // Seek to beginning and read the Exif data
                 io_->seek(8-bufRead, BasicIo::cur);
                 long sizeExifData = size - 8;
                 DataBuf rawExif(sizeExifData);
                 io_->read(rawExif.pData_, sizeExifData);
                 if (io_->error() || io_->eof()) throw Error(14);
-                if (exifData_.load(rawExif.pData_, sizeExifData)) throw Error(36, "Exif");
+                if (exifData_.load(rawExif.pData_, sizeExifData)) {
+#ifndef SUPPRESS_WARNINGS
+                    std::cerr << "Warning: Failed to decode Exif metadata.\n";
+#endif
+                    exifData_.clear();
+                }
                 --search;
             }
-            else if (marker == app13_ && memcmp(buf.pData_ + 2, Photoshop::ps3Id_, 14) == 0) {
-                if (size < 16) throw Error(15);
+            else if (   marker == app13_
+                     && memcmp(buf.pData_ + 2, Photoshop::ps3Id_, 14) == 0) {
+                if (size < 16) {
+                    rc = 2;
+                    break;
+                }
                 // Read the rest of the APP13 segment
                 // needed if bufMinSize!=16: io_->seek(16-bufRead, BasicIo::cur);
                 DataBuf psData(size - 16);
@@ -262,14 +276,22 @@ namespace Exiv2 {
                 if (!Photoshop::locateIptcIrb(psData.pData_, psData.size_,
                                               &record, &sizeHdr, &sizeIptc)) {
                     if (sizeIptc) {
-                        if (iptcData_.load(record + sizeHdr, sizeIptc)) throw Error(36, "IPTC");
+                        if (iptcData_.load(record + sizeHdr, sizeIptc)) {
+#ifndef SUPPRESS_WARNINGS
+                            std::cerr << "Warning: Failed to decode IPTC metadata.\n";
+#endif
+                            iptcData_.clear();
+                        }
                     }
                 }
                 --search;
             }
             else if (marker == com_ && comment_.empty())
             {
-                if (size < 2) throw Error(15);
+                if (size < 2) {
+                    rc = 3;
+                    break;
+                }
                 // Jpegs can have multiple comments, but for now only read
                 // the first one (most jpegs only have one anyway). Comments
                 // are simple single byte ISO-8859-1 strings.
@@ -285,13 +307,24 @@ namespace Exiv2 {
                 --search;
             }
             else {
-                if (size < 2) throw Error(15);
+                if (size < 2) {
+                    rc = 4;
+                    break;
+                }
                 // Skip the remainder of the unknown segment
-                if (io_->seek(size-bufRead, BasicIo::cur)) throw Error(15);
+                if (io_->seek(size-bufRead, BasicIo::cur)) throw Error(14);
             }
             // Read the beginning of the next segment
             marker = advanceToMarker();
-            if (marker < 0) throw Error(15);
+            if (marker < 0) {
+                rc = 5;
+                break;
+            }
+        } // while there are segments to process
+        if (rc != 0) {
+#ifndef SUPPRESS_WARNINGS
+            std::cerr << "Warning: JPEG format error, rc = " << rc << "\n";
+#endif
         }
     } // JpegBase::readMetadata
 
