@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2006 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2006-2007 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,14 +20,14 @@
  */
 /*
   File:      mrwimage.cpp
-  Version:   $Rev: 837 $
+  Version:   $Rev: 1047 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   13-May-06, ahu: created
   Credits:   See header file
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: mrwimage.cpp 837 2006-06-25 09:42:59Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: mrwimage.cpp 1047 2007-02-07 13:56:29Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -54,60 +54,27 @@ EXIV2_RCSID("@(#) $Id: mrwimage.cpp 837 2006-06-25 09:42:59Z ahuggel $")
 // class member definitions
 namespace Exiv2 {
 
-    MrwImage::MrwImage(BasicIo::AutoPtr io, bool create)
-        : Image(mdExif | mdIptc), io_(io)
+    MrwImage::MrwImage(BasicIo::AutoPtr io, bool /*create*/)
+        : Image(ImageType::mrw, mdExif | mdIptc, io)
     {
-        if (create) {
-            IoCloser closer(*io_);
-            io_->open();
-        }
     } // MrwImage::MrwImage
 
-    bool MrwImage::good() const
+    void MrwImage::setExifData(const ExifData& /*exifData*/)
     {
-        if (io_->open() != 0) return false;
-        IoCloser closer(*io_);
-        return isThisType(*io_, false);
+        // Todo: implement me!
+        throw(Error(32, "Exif metadata", "MRW"));
     }
 
-    void MrwImage::clearMetadata()
+    void MrwImage::setIptcData(const IptcData& /*iptcData*/)
     {
-        clearExifData();
-    }
-
-    void MrwImage::setMetadata(const Image& image)
-    {
-        setExifData(image.exifData());
-    }
-
-    void MrwImage::clearExifData()
-    {
-        exifData_.clear();
-    }
-
-    void MrwImage::setExifData(const ExifData& exifData)
-    {
-        exifData_ = exifData;
-    }
-
-    void MrwImage::clearIptcData()
-    {
-        iptcData_.clear();
-    }
-
-    void MrwImage::setIptcData(const IptcData& iptcData)
-    {
-        iptcData_ = iptcData;
-    }
-
-    void MrwImage::clearComment()
-    {
-        // not supported
+        // Todo: implement me!
+        throw(Error(32, "IPTC metadata", "MRW"));
     }
 
     void MrwImage::setComment(const std::string& /*comment*/)
     {
         // not supported
+        throw(Error(32, "Image comment", "MRW"));
     }
 
     void MrwImage::readMetadata()
@@ -120,7 +87,7 @@ namespace Exiv2 {
         }
         IoCloser closer(*io_);
         // Ensure that this is the correct image type
-        if (!isThisType(*io_, false)) {
+        if (!isMrwType(*io_, false)) {
             if (io_->error() || io_->eof()) throw Error(14);
             throw Error(3, "MRW");
         }
@@ -155,60 +122,18 @@ namespace Exiv2 {
         io_->read(buf.pData_, buf.size_);
         if (io_->error() || io_->eof()) throw Error(14);
 
-        TiffParser::decode(this, buf.pData_, buf.size_, 
+        TiffParser::decode(this, buf.pData_, buf.size_,
                            TiffCreator::create, TiffDecoder::findDecoder);
     } // MrwImage::readMetadata
 
     void MrwImage::writeMetadata()
     {
-/*
-
-       Todo: implement me!
-
-#ifdef DEBUG
-        std::cerr << "Writing MRW file " << io_->path() << "\n";
-#endif
-        // Read existing image
-        DataBuf buf;
-        if (io_->open() == 0) {
-            IoCloser closer(*io_);
-            // Ensure that this is the correct image type
-            if (isThisType(*io_, false)) {
-                // Read the image into a memory buffer
-                buf.alloc(io_->size());
-                io_->read(buf.pData_, buf.size_);
-                if (io_->error() || io_->eof()) {
-                    buf.reset();
-                }
-            }
-        }
-
-        // Parse image, starting with a MRW header component
-        TiffHeade2::AutoPtr head(new TiffHeade2);
-        if (buf.size_ != 0) {
-            head->read(buf.pData_, buf.size_);
-        }
-
-        Blob blob;
-        TiffParser::encode(blob, head.get(), this);
-
-        // Write new buffer to file
-        BasicIo::AutoPtr tempIo(io_->temporary()); // may throw
-        assert (tempIo.get() != 0);
-        tempIo->write(&blob[0], static_cast<long>(blob.size()));
-        io_->close();
-        io_->transfer(*tempIo); // may throw
-*/
+        // Todo: implement me!
+        throw(Error(31, "MRW"));
     } // MrwImage::writeMetadata
 
-    bool MrwImage::isThisType(BasicIo& iIo, bool advance) const
-    {
-        return isMrwType(iIo, advance);
-    }
-
     // *************************************************************************
     // free functions
-
     Image::AutoPtr newMrwInstance(BasicIo::AutoPtr io, bool create)
     {
         Image::AutoPtr image(new MrwImage(io, create));
