@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004, 2005, 2006 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2007 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -29,9 +29,11 @@
   Email communication with <a href="http://www.rottmerhusen.com">Robert Rottmerhusen</a><BR>
   Email communication with Roger Larsson<BR>
 
-  @version $Rev: 870 $
+  @version $Rev: 1039 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
+  @author  Gilles Caulier (gc)
+           <a href="mailto:caulier dot gilles at kdemail dot net">caulier dot gilles at kdemail dot net</a>
   @date    17-May-04, ahu: created<BR>
            25-May-04, ahu: combined all Nikon formats in one component
  */
@@ -114,6 +116,8 @@ namespace Exiv2 {
         //@{
         AutoPtr create(bool alloc =true) const;
         AutoPtr clone() const;
+        //! Return read-only list of built-in Nikon1 tags
+        static const TagInfo* tagList();
         //@}
 
         //! @name Print functions for Nikon1 %MakerNote tags
@@ -184,6 +188,8 @@ namespace Exiv2 {
         int checkHeader() const;
         AutoPtr create(bool alloc =true) const;
         AutoPtr clone() const;
+        //! Return read-only list of built-in Nikon2 tags
+        static const TagInfo* tagList();
         //@}
 
         //! @name Print functions for Nikon2 %MakerNote tags
@@ -243,14 +249,24 @@ namespace Exiv2 {
         int checkHeader() const;
         AutoPtr create(bool alloc =true) const;
         AutoPtr clone() const;
+        //! Return read-only list of built-in Nikon3 tags
+        static const TagInfo* tagList();
         //@}
 
         //! @name Print functions for Nikon3 %MakerNote tags
         //@{
         //! Print ISO setting
         static std::ostream& print0x0002(std::ostream& os, const Value& value);
+        //! Print autofocus mode
+        static std::ostream& print0x0007(std::ostream& os, const Value& value);
+        //! Print lens type
+        static std::ostream& print0x0083(std::ostream& os, const Value& value);
         //! Print lens information
         static std::ostream& print0x0084(std::ostream& os, const Value& value);
+        //! Print manual focus distance
+        static std::ostream& print0x0085(std::ostream& os, const Value& value);
+        //! Print digital zoom setting
+        static std::ostream& print0x0086(std::ostream& os, const Value& value);
         //! Print AF point
         static std::ostream& print0x0088(std::ostream& os, const Value& value);
         //! Print number of lens stops
