@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004, 2005, 2006 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2007 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,13 +20,13 @@
  */
 /*
   File:      sonymn.cpp
-  Version:   $Rev: 986 $
+  Version:   $Rev: 1039 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   18-Apr-05, ahu: created
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: sonymn.cpp 986 2006-11-21 15:43:11Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: sonymn.cpp 1039 2007-02-02 10:09:31Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -34,6 +34,7 @@ EXIV2_RCSID("@(#) $Id: sonymn.cpp 986 2006-11-21 15:43:11Z ahuggel $")
 #include "sonymn.hpp"
 #include "makernote.hpp"
 #include "value.hpp"
+#include "i18n.h"                // NLS support.
 
 // + standard includes
 #include <string>
@@ -58,17 +59,37 @@ namespace Exiv2 {
 
     // Sony MakerNote Tag Info
     const TagInfo SonyMakerNote::tagInfo_[] = {
-        TagInfo(0x2000, "0x2000", "0x2000", "Unknown", sonyIfdId, makerTags, undefined, printValue),
-        TagInfo(0x9001, "0x9001", "0x9001", "Unknown", sonyIfdId, makerTags, undefined, printValue),
-        TagInfo(0x9002, "0x9002", "0x9002", "Unknown", sonyIfdId, makerTags, undefined, printValue),
-        TagInfo(0x9003, "0x9003", "0x9003", "Unknown", sonyIfdId, makerTags, undefined, printValue),
-        TagInfo(0x9004, "0x9004", "0x9004", "Unknown", sonyIfdId, makerTags, undefined, printValue),
-        TagInfo(0x9005, "0x9005", "0x9005", "Unknown", sonyIfdId, makerTags, undefined, printValue),
-        TagInfo(0x9006, "0x9006", "0x9006", "Unknown", sonyIfdId, makerTags, undefined, printValue),
-        TagInfo(0x9007, "0x9007", "0x9007", "Unknown", sonyIfdId, makerTags, undefined, printValue),
-        TagInfo(0x9008, "0x9008", "0x9008", "Unknown", sonyIfdId, makerTags, undefined, printValue),
+        TagInfo(0x2000, "0x2000", "0x2000",
+                N_("Unknown"),
+                sonyIfdId, makerTags, undefined, printValue),
+        TagInfo(0x9001, "0x9001", "0x9001",
+                N_("Unknown"),
+                sonyIfdId, makerTags, undefined, printValue),
+        TagInfo(0x9002, "0x9002", "0x9002",
+                N_("Unknown"),
+                sonyIfdId, makerTags, undefined, printValue),
+        TagInfo(0x9003, "0x9003", "0x9003",
+                N_("Unknown"),
+                sonyIfdId, makerTags, undefined, printValue),
+        TagInfo(0x9004, "0x9004", "0x9004",
+                N_("Unknown"),
+                sonyIfdId, makerTags, undefined, printValue),
+        TagInfo(0x9005, "0x9005", "0x9005",
+                N_("Unknown"),
+                sonyIfdId, makerTags, undefined, printValue),
+        TagInfo(0x9006, "0x9006", "0x9006",
+                N_("Unknown"),
+                sonyIfdId, makerTags, undefined, printValue),
+        TagInfo(0x9007, "0x9007", "0x9007",
+                N_("Unknown"),
+                sonyIfdId, makerTags, undefined, printValue),
+        TagInfo(0x9008, "0x9008", "0x9008",
+                N_("Unknown"),
+                sonyIfdId, makerTags, undefined, printValue),
         // End of list marker
-        TagInfo(0xffff, "(UnknownSonyMakerNoteTag)", "Unknown SonyMakerNote tag", "Unknown SonyMakerNote tag", sonyIfdId, makerTags, invalidTypeId, printValue)
+        TagInfo(0xffff, "(UnknownSonyMakerNoteTag)", "(UnknownSonyMakerNoteTag)",
+                N_("Unknown SonyMakerNote tag"),
+                sonyIfdId, makerTags, invalidTypeId, printValue)
     };
 
     const TagInfo* SonyMakerNote::tagList()
