@@ -20,7 +20,7 @@
  */
 /*
   File:      tags.cpp
-  Version:   $Rev: 1039 $
+  Version:   $Rev: 1113 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
              Gilles Caulier (gc) <caulier.gilles@kdemail.net>
   History:   15-Jan-04, ahu: created
@@ -28,7 +28,7 @@
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: tags.cpp 1039 2007-02-02 10:09:31Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: tags.cpp 1113 2007-06-03 08:32:16Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -225,6 +225,10 @@ namespace Exiv2 {
 
     //! Base IFD Tags (IFD0 and IFD1)
     static const TagInfo ifdTagInfo[] = {
+        TagInfo(0x000b, "ProcessingSoftware", N_("Processing Software"),
+                N_("The name and version of the software used to post-process "
+                   "the picture."), // ACD Systems Digital Imaging tag
+                ifd0Id, otherTags, asciiString, printValue),
         TagInfo(0x00fe, "NewSubfileType", N_("New Subfile Type"),
                 N_("A general indication of the kind of data contained in this subfile."),
                 ifd0Id, imgStruct, unsignedLong, EXV_PRINT_TAG(exifNewSubfileType)), // TIFF tag
@@ -343,7 +347,8 @@ namespace Exiv2 {
                 "image creator. The detailed format is not specified, but it is "
                 "recommended that the information be written as in the example "
                 "below for ease of Interoperability. When the field is "
-                "left blank, it is treated as unknown."),
+                "left blank, it is treated as unknown. Ex.) \"Camera owner, John "
+                "Smith; Photographer, Michael Brown; Image creator, Ken James\""),
                 ifd0Id, otherTags, asciiString, printValue),
         TagInfo(0x013e, "WhitePoint", N_("White Point"),
                 N_("The chromaticity of the white point of the image. Normally "
@@ -416,6 +421,12 @@ namespace Exiv2 {
         TagInfo(0x02bc, "XMLPacket", N_("XML Packet"),
                 N_("XMP Metadata (Adobe technote 9-14-02)"),
                 ifd0Id, otherTags, unsignedByte, printValue),
+        TagInfo(0x4746, "Rating", N_("Windows Rating"),
+                N_("Rating tag used by Windows"),
+                ifd0Id, otherTags, unsignedShort, printValue), // Windows Tag
+        TagInfo(0x4749, "RatingPercent", N_("Windows Rating Percent"),
+                N_("Rating tag used by Windows, value in percent"),
+                ifd0Id, otherTags, unsignedShort, printValue), // Windows Tag
         TagInfo(0x828d, "CFARepeatPatternDim", N_("CFA Repeat Pattern Dimension"),
                 N_("Contains two values representing the minimum rows and columns "
                 "to define the repeating patterns of the color filter array"),
@@ -440,8 +451,16 @@ namespace Exiv2 {
                 "field; e.g., \"Copyright, John Smith, 19xx. All rights "
                 "reserved.\". In this standard the field records both the "
                 "photographer and editor copyrights, with each recorded in a "
-                "separate part of the statement. When the field "
-                "is left blank, it is treated as unknown."),
+                "separate part of the statement. When there is a clear distinction "
+                "between the photographer and editor copyrights, these are to be "
+                "written in the order of photographer followed by editor copyright, "
+                "separated by NULL (in this case since the statement also ends with "
+                "a NULL, there are two NULL codes). When only the photographer "
+                "copyright is given, it is terminated by one NULL code . When only "
+                "the editor copyright is given, the photographer copyright part "
+                "consists of one space followed by a terminating NULL code, then "
+                "the editor copyright is given. When the field is left blank, it is "
+                "treated as unknown."),
                 ifd0Id, otherTags, asciiString, print0x8298),
         TagInfo(0x8649, "ImageResources", N_("Image Resources Block"),
                 N_("Contains information embedded by the Adobe Photoshop application"),
@@ -1667,7 +1686,7 @@ namespace Exiv2 {
 
     std::ostream& printUcs2(std::ostream& os, const Value& value)
     {
-#ifdef EXV_HAVE_ICONV
+#if defined EXV_HAVE_ICONV && defined EXV_HAVE_PRINTUCS2
         bool go = true;
         iconv_t cd = (iconv_t)(-1);
         if (value.typeId() != unsignedByte) {
@@ -1716,9 +1735,9 @@ namespace Exiv2 {
         if (!go) {
             os << value;
         }
-#else // !EXV_HAVE_ICONV
+#else // !(EXV_HAVE_ICONV && EXV_HAVE_PRINTUCS2)
         os << value;
-#endif // EXV_HAVE_ICONV
+#endif // EXV_HAVE_ICONV && EXV_HAVE_PRINTUCS2
         return os;
 
     } // printUcs2
