@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2006 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2006-2007 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,14 +20,14 @@
  */
 /*
   File:      tiffimage.cpp
-  Version:   $Rev: 838 $
+  Version:   $Rev: 1047 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   15-Mar-06, ahu: created
 
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: tiffimage.cpp 838 2006-06-25 18:11:01Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: tiffimage.cpp 1047 2007-02-07 13:56:29Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -42,6 +42,7 @@ EXIV2_RCSID("@(#) $Id: tiffimage.cpp 838 2006-06-25 18:11:01Z ahuggel $")
 #include "image.hpp"
 #include "error.hpp"
 #include "futils.hpp"
+#include "i18n.h"                // NLS support.
 
 // + standard includes
 #include <string>
@@ -53,62 +54,27 @@ EXIV2_RCSID("@(#) $Id: tiffimage.cpp 838 2006-06-25 18:11:01Z ahuggel $")
 // class member definitions
 namespace Exiv2 {
 
-    TiffImage::TiffImage(BasicIo::AutoPtr io, bool create)
-        : Image(mdExif | mdIptc | mdComment), io_(io)
+    TiffImage::TiffImage(BasicIo::AutoPtr io, bool /*create*/)
+        : Image(ImageType::tiff, mdExif | mdIptc, io)
     {
-        if (create) {
-            IoCloser closer(*io_);
-            io_->open();
-        }
     } // TiffImage::TiffImage
 
-    bool TiffImage::good() const
+    void TiffImage::setExifData(const ExifData& /*exifData*/)
     {
-        if (io_->open() != 0) return false;
-        IoCloser closer(*io_);
-        return isThisType(*io_, false);
+        // Todo: implement me!
+        throw(Error(32, "Exif metadata", "TIFF"));
     }
 
-    void TiffImage::clearMetadata()
+    void TiffImage::setIptcData(const IptcData& /*iptcData*/)
     {
-        clearExifData();
-        clearComment();
+        // Todo: implement me!
+        throw(Error(32, "IPTC metadata", "TIFF"));
     }
 
-    void TiffImage::setMetadata(const Image& image)
+    void TiffImage::setComment(const std::string& /*comment*/)
     {
-        setExifData(image.exifData());
-        setComment(image.comment());
-    }
-
-    void TiffImage::clearExifData()
-    {
-        exifData_.clear();
-    }
-
-    void TiffImage::setExifData(const ExifData& exifData)
-    {
-        exifData_ = exifData;
-    }
-
-    void TiffImage::clearIptcData()
-    {
-        iptcData_.clear();
-    }
-
-    void TiffImage::setIptcData(const IptcData& iptcData)
-    {
-        iptcData_ = iptcData;
-    }
-
-    void TiffImage::clearComment()
-    {
-        comment_.erase();
-    }
-
-    void TiffImage::setComment(const std::string& comment)
-    {
-        comment_ = comment;
+        // not supported
+        throw(Error(32, "Image comment", "TIFF"));
     }
 
     void TiffImage::readMetadata()
@@ -116,68 +82,24 @@ namespace Exiv2 {
 #ifdef DEBUG
         std::cerr << "Reading TIFF file " << io_->path() << "\n";
 #endif
-        if (io_->open() != 0) {
-            throw Error(9, io_->path(), strError());
-        }
+        if (io_->open() != 0) throw Error(9, io_->path(), strError());
         IoCloser closer(*io_);
         // Ensure that this is the correct image type
-        if (!isThisType(*io_, false)) {
+        if (!isTiffType(*io_, false)) {
             if (io_->error() || io_->eof()) throw Error(14);
-            throw Error(33);
+            throw Error(3, "TIFF");
         }
         clearMetadata();
         TiffParser::decode(this, io_->mmap(), io_->size(),
                            TiffCreator::create, TiffDecoder::findDecoder);
-
     } // TiffImage::readMetadata
 
     void TiffImage::writeMetadata()
     {
-/*
-
-       Todo: implement me!
-
-#ifdef DEBUG
-        std::cerr << "Writing TIFF file " << io_->path() << "\n";
-#endif
-        // Read existing image
-        DataBuf buf;
-        if (io_->open() == 0) {
-            IoCloser closer(*io_);
-            // Ensure that this is the correct image type
-            if (isThisType(*io_, false)) {
-                // Read the image into a memory buffer
-                buf.alloc(io_->size());
-                io_->read(buf.pData_, buf.size_);
-                if (io_->error() || io_->eof()) {
-                    buf.reset();
-                }
-            }
-        }
-
-        // Parse image, starting with a TIFF header component
-        TiffHeade2::AutoPtr head(new TiffHeade2);
-        if (buf.size_ != 0) {
-            head->read(buf.pData_, buf.size_);
-        }
-
-        Blob blob;
-        TiffParser::encode(blob, head.get(), this);
-
-        // Write new buffer to file
-        BasicIo::AutoPtr tempIo(io_->temporary()); // may throw
-        assert (tempIo.get() != 0);
-        tempIo->write(&blob[0], static_cast<long>(blob.size()));
-        io_->close();
-        io_->transfer(*tempIo); // may throw
-*/
+        //! Todo: implement me!
+        throw(Error(31, "TIFF"));
     } // TiffImage::writeMetadata
 
-    bool TiffImage::isThisType(BasicIo& iIo, bool advance) const
-    {
-        return isTiffType(iIo, advance);
-    }
-
     const uint16_t TiffHeade2::tag_ = 42;
 
     bool TiffHeade2::read(const byte* pData, uint32_t size)
@@ -202,21 +124,19 @@ namespace Exiv2 {
     void TiffHeade2::print(std::ostream& os, const std::string& prefix) const
     {
         os << prefix
-           << "Header, offset = 0x" << std::setw(8) << std::setfill('0')
+           << _("Header, offset") << " = 0x" << std::setw(8) << std::setfill('0')
            << std::hex << std::right << offset_;
 
         switch (byteOrder_) {
-        case littleEndian:     os << ", little endian encoded"; break;
-        case bigEndian:        os << ", big endian encoded"; break;
+        case littleEndian:     os << ", " << _("little endian encoded"); break;
+        case bigEndian:        os << ", " << _("big endian encoded");    break;
         case invalidByteOrder: break;
         }
         os << "\n";
-
     } // TiffHeade2::print
 
     // *************************************************************************
     // free functions
-
     Image::AutoPtr newTiffInstance(BasicIo::AutoPtr io, bool create)
     {
         Image::AutoPtr image(new TiffImage(io, create));
