@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2006 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2006-2007 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,14 +20,14 @@
  */
 /*
   File:      tiffparser.cpp
-  Version:   $Rev: 866 $
+  Version:   $Rev: 1039 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   15-Mar-06, ahu: created
 
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: tiffparser.cpp 866 2006-08-24 15:24:12Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: tiffparser.cpp 1039 2007-02-02 10:09:31Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -142,15 +142,16 @@ namespace Exiv2 {
         { "*",         0x014a, Group::ifd0,    0 }, // Todo: Controversial, causes problems with Exiftool
         { "*",       Tag::all, Group::sub0_0,  &TiffMetadataDecoder::decodeSubIfd       },
         { "*",       Tag::all, Group::sub0_1,  &TiffMetadataDecoder::decodeSubIfd       },
-        { "*",         0x8649, Group::ifd0,    &TiffMetadataDecoder::decodeIrbIptc      }
+        { "*",         0x83bb, Group::ifd0,    &TiffMetadataDecoder::decodeIptc         },
+        { "*",         0x8649, Group::ifd0,    &TiffMetadataDecoder::decodeIptc         }
     };
 
-    const DecoderFct TiffDecoder::findDecoder(const std::string& make, 
+    const DecoderFct TiffDecoder::findDecoder(const std::string& make,
                                                     uint32_t     extendedTag,
                                                     uint16_t     group)
     {
         DecoderFct decoderFct = &TiffMetadataDecoder::decodeStdTiffEntry;
-        const TiffDecoderInfo* td = find(tiffDecoderInfo_, 
+        const TiffDecoderInfo* td = find(tiffDecoderInfo_,
                                          TiffDecoderInfo::Key(make, extendedTag, group));
         if (td) {
             // This may set decoderFct to 0, meaning that the tag should not be decoded
