@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2006 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2006-2007 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,13 +20,13 @@
  */
 /*
   File:      tiffvisitor.cpp
-  Version:   $Rev: 943 $
+  Version:   $Rev: 1040 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   11-Apr-06, ahu: created
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: tiffvisitor.cpp 943 2006-11-06 15:48:14Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: tiffvisitor.cpp 1040 2007-02-02 10:11:43Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -45,6 +45,7 @@ EXIV2_RCSID("@(#) $Id: tiffvisitor.cpp 943 2006-11-06 15:48:14Z ahuggel $")
 #include "value.hpp"
 #include "image.hpp"
 #include "jpgimage.hpp"
+#include "i18n.h"             // NLS support.
 
 // + standard includes
 #include <string>
@@ -120,10 +121,11 @@ namespace Exiv2 {
                                              TiffComponent* const pRoot,
                                              FindDecoderFct findDecoderFct,
                                              uint32_t threshold)
-        : pImage_(pImage), 
+        : pImage_(pImage),
           pRoot_(pRoot),
           findDecoderFct_(findDecoderFct),
-          threshold_(threshold)
+          threshold_(threshold),
+          decodedIptc_(false)
     {
         // Find camera make
         TiffFinder finder(0x010f, Group::ifd0);
@@ -184,32 +186,78 @@ namespace Exiv2 {
         }
     }
 
-    void TiffMetadataDecoder::decodeIrbIptc(const TiffEntryBase* object)
+    void TiffMetadataDecoder::getObjData(byte const*& pData,
+                                         long& size,
+                                         uint16_t tag,
+                                         uint16_t group,
+                                         const TiffEntryBase* object)
     {
-        assert(object != 0);
-        assert(pImage_ != 0);
-        if (!object->pData()) return;
-        byte const* record = 0;
-        uint32_t sizeHdr = 0;
-        uint32_t sizeData = 0;
-        if (0 != Photoshop::locateIptcIrb(object->pData(), object->size(),
-                                          &record, &sizeHdr, &sizeData)) {
+        if (object && object->tag() == tag && object->group() == group) {
+            pData = object->pData();
+            size = object->size();
             return;
         }
-        if (0 != pImage_->iptcData().load(record + sizeHdr, sizeData)) {
-#ifndef SUPPRESS_WARNINGS
-            std::cerr << "Warning: Failed to decode IPTC block found in "
-                      << "Directory " << object->groupName()
-                      << ", entry 0x" << std::setw(4)
-                      << std::setfill('0') << std::hex << object->tag()
-                      << "\n";
-#endif
-            // Todo: ExifKey should have an appropriate c'tor, it should not be
-            //       necessary to use groupName here
-            ExifKey key(object->tag(), object->groupName());
-            setExifTag(key, object->pValue());
+        TiffFinder finder(tag, group);
+        pRoot_->accept(finder);
+        TiffEntryBase const* te = dynamic_cast<TiffEntryBase*>(finder.result());
+        if (te) {
+            pData = te->pData();
+            size = te->size();
+            return;
         }
-    } // TiffMetadataDecoder::decodeIrbIptc
+    }
+
+    void TiffMetadataDecoder::decodeIptc(const TiffEntryBase* object)
+    {
+        // add Exif tag anyway
+        decodeStdTiffEntry(object);
+
+        // All tags are read at this point, so the first time we come here,
+        // find the relevant IPTC tag and decode IPTC if found
+        if (decodedIptc_) {
+            return;
+        }
+        decodedIptc_ = true;
+        // 1st choice: IPTCNAA
+        byte const* pData = 0;
+        long size = 0;
+        getObjData(pData, size, 0x83bb, Group::ifd0, object);
+        if (pData) {
+            if (0 == pImage_->iptcData().load(pData, size)) {
+                return;
+            }
+#ifndef SUPPRESS_WARNINGS
+            else {
+                std::cerr << "Warning: Failed to decode IPTC block found in "
+                          << "Directory Image, entry 0x83bb\n";
+            }
+#endif
+        }
+
+        // 2nd choice if no IPTCNAA record found or failed to decode it:
+        // ImageResources
+        pData = 0;
+        size = 0;
+        getObjData(pData, size, 0x8649, Group::ifd0, object);
+        if (pData) {
+            byte const* record = 0;
+            uint32_t sizeHdr = 0;
+            uint32_t sizeData = 0;
+            if (0 != Photoshop::locateIptcIrb(pData, size,
+                                              &record, &sizeHdr, &sizeData)) {
+                return;
+            }
+            if (0 == pImage_->iptcData().load(record + sizeHdr, sizeData)) {
+                return;
+            }
+#ifndef SUPPRESS_WARNINGS
+            else {
+                std::cerr << "Warning: Failed to decode IPTC block found in "
+                          << "Directory Image, entry 0x8649\n";
+            }
+#endif
+        }
+    } // TiffMetadataDecoder::decodeIptc
 
     void TiffMetadataDecoder::decodeSubIfd(const TiffEntryBase* object)
     {
@@ -239,7 +287,7 @@ namespace Exiv2 {
             groupType_[object->group()] = object->pValue()->toLong();
         }
 
-        const DecoderFct decoderFct = findDecoderFct_(make_, 
+        const DecoderFct decoderFct = findDecoderFct_(make_,
                                                       object->tag(),
                                                       object->group());
         // skip decoding if decoderFct == 0
@@ -316,9 +364,9 @@ namespace Exiv2 {
     {
         printTiffEntry(object, prefix());
         if (object->pValue()) {
-            os_ << prefix() << "Data area "
+            os_ << prefix() << _("Data area") << " "
                 << object->pValue()->sizeDataArea()
-                << " bytes.\n";
+                << " " << _("bytes.\n");
         }
     } // TiffPrinter::visitEntry
 
@@ -331,11 +379,11 @@ namespace Exiv2 {
     {
         assert(object != 0);
 
-        os_ << prefix() << object->groupName() << " directory with "
+        os_ << prefix() << object->groupName() << " " << _("directory with") << " "
         // cast to make MSVC happy
            << std::dec << static_cast<unsigned int>(object->components_.size());
-        if (object->components_.size() == 1) os_ << " entry:\n";
-        else os_ << " entries:\n";
+        if (object->components_.size() == 1) os_ << " " << _("entry:\n");
+        else os_ << " " << _("entries:\n");
         incIndent();
 
     } // TiffPrinter::visitDirectory
@@ -344,8 +392,8 @@ namespace Exiv2 {
     {
         decIndent();
         if (object->hasNext()) {
-            if (object->pNext_) os_ << prefix() << "Next directory:\n";
-            else os_ << prefix() << "No next directory\n";
+            if (object->pNext_) os_ << prefix() << _("Next directory:\n");
+            else os_ << prefix() << _("No next directory\n");
         }
     } // TiffPrinter::visitDirectoryNext
 
@@ -356,14 +404,14 @@ namespace Exiv2 {
 
     void TiffPrinter::visitSubIfd(TiffSubIfd* object)
     {
-        os_ << prefix() << "Sub-IFD ";
+        os_ << prefix() << _("Sub-IFD") << " ";
         printTiffEntry(object);
     } // TiffPrinter::visitSubIfd
 
     void TiffPrinter::visitMnEntry(TiffMnEntry* object)
     {
         if (!object->mn_) printTiffEntry(object, prefix());
-        else os_ << prefix() << "Makernote ";
+        else os_ << prefix() << _("Makernote") << " ";
     } // TiffPrinter::visitMnEntry
 
     void TiffPrinter::visitIfdMakernote(TiffIfdMakernote* /*object*/)
@@ -377,13 +425,13 @@ namespace Exiv2 {
         assert(object != 0);
 
         os_ << px << object->groupName()
-            << " tag 0x" << std::setw(4) << std::setfill('0')
+            << " " << _("tag") << " 0x" << std::setw(4) << std::setfill('0')
             << std::hex << std::right << object->tag()
-            << ", type " << TypeInfo::typeName(object->typeId())
-            << ", " << std::dec << object->count() << " component";
+            << ", " << _("type") << " " << TypeInfo::typeName(object->typeId())
+            << ", " << std::dec << object->count() << " "<< _("component");
         if (object->count() > 1) os_ << "s";
-        os_ << " in " << object->size() << " bytes";
-        if (object->size() > 4) os_ << ", offset " << object->offset();
+        os_ << " in " << object->size() << " " << _("bytes");
+        if (object->size() > 4) os_ << ", " << _("offset") << " " << object->offset();
         os_ << "\n";
         const Value* vp = object->pValue();
         if (vp && vp->count() < 100) os_ << prefix() << *vp;
@@ -399,8 +447,8 @@ namespace Exiv2 {
             printTiffEntry(object, prefix());
         }
         else {
-            os_ << prefix() << "Array Entry " << object->groupName()
-                << " tag 0x" << std::setw(4) << std::setfill('0')
+            os_ << prefix() << _("Array Entry") << " " << object->groupName()
+                << " " << _("tag") << " 0x" << std::setw(4) << std::setfill('0')
                 << std::hex << std::right << object->tag() << "\n";
         }
     } // TiffPrinter::visitArrayEntry
@@ -515,7 +563,7 @@ namespace Exiv2 {
         long offset = pOffset->toLong(0);
         // Todo: Remove limitation of Jpeg writer: strips must be contiguous
         // Until then we check: last offset + last size - first offset == size?
-        if (  pOffset->toLong(pOffset->count()-1) 
+        if (  pOffset->toLong(pOffset->count()-1)
             + pSize->toLong(pSize->count()-1)
             - offset != size) {
 #ifndef SUPPRESS_WARNINGS
@@ -560,8 +608,8 @@ namespace Exiv2 {
         // Sanity check with an "unreasonably" large number
         if (n > 256) {
 #ifndef SUPPRESS_WARNINGS
-            std::cerr << "Error: " 
-                      << "Directory " << object->groupName() << " with " 
+            std::cerr << "Error: "
+                      << "Directory " << object->groupName() << " with "
                       << n << " entries considered invalid; not read.\n";
 #endif
             return;
@@ -796,8 +844,8 @@ namespace Exiv2 {
         // Todo: This should be somewhere else, maybe in a Value factory
         // which takes a Key and Type
         TypeId t = TypeId(object->typeId());
-        if (   object->tag()    == 0x9286 
-            && object->group()  == Group::exif 
+        if (   object->tag()    == 0x9286
+            && object->group()  == Group::exif
             && object->typeId() == undefined) {
             t = comment;
         }
