@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004, 2005, 2006 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2007 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,18 +20,19 @@
  */
 /*
   File:      types.cpp
-  Version:   $Rev: 832 $
+  Version:   $Rev: 1039 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   26-Jan-04, ahu: created
              11-Feb-04, ahu: isolated as a component
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: types.cpp 832 2006-06-21 09:16:36Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: types.cpp 1039 2007-02-02 10:09:31Z ahuggel $")
 
 // *****************************************************************************
 // included header files
 #include "types.hpp"
+#include "i18n.h"                               // for _exvGettext
 
 // + standard includes
 #include <string>
@@ -334,4 +335,30 @@ namespace Exiv2 {
         return rc;
     } // exifTime
 
+    const char* exvGettext(const char* str)
+    {
+#ifdef EXV_ENABLE_NLS
+        return _exvGettext(str);
+#else
+        return str;
+#endif
+    }
 }                                       // namespace Exiv2
+
+#ifdef EXV_ENABLE_NLS
+// Declaration is in i18n.h
+const char* _exvGettext(const char* str)
+{
+    static bool exvGettextInitialized = false;
+
+    if (!exvGettextInitialized) {
+        bindtextdomain(EXV_PACKAGE, EXV_LOCALEDIR);
+# ifdef EXV_HAVE_BIND_TEXTDOMAIN_CODESET
+        bind_textdomain_codeset (EXV_PACKAGE, "UTF-8");
+# endif
+        exvGettextInitialized = true;
+    }
+
+    return dgettext(EXV_PACKAGE, str);
+}
+#endif // EXV_ENABLE_NLS
